@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use vars qw($VERSION);
 
-$VERSION='0.1.1';
+$VERSION='0.1';
 
 use Net::SMTP::SSL;
 use MIME::Base64;
@@ -215,22 +215,15 @@ Email::Send::SMTP::Gmail - just send emails with attachments using Google's SMTP
 
 =head1 SYNOPSIS
 
-                 use strict;
-                 use warnings;
+use Email::Send::SMTP::Gmail;
 
-                 use Email::Send::SMTP::Gmail;
+my $mail=Email::Send::SMTP::Gmail->new( -smtp=>'gmail.com',
+                                        -login=>'add_your_address@gmail.com',
+                                        -pass=>'add_your_pass');
 
-                 my $mail=Email::Send::SMTP::Gmail->new( -smtp=>'gmail.com',
-                                                         -login=>'add_your_address@gmail.com',
-                                                         -pass=>'add_your_pass');
+$mail->send(-to=>'target@xxx.com', -subject=>'Hello!', -verbose=>'1', -body=>'Just testing it', -attachments=>'full_path_to_file');
 
-                $mail->send(-to=>'target@xxx.com',
-                            -subject=>'Hello!',
-                            -verbose=>'1',
-                            -body=>'Just testing it',
-                            -attachments=>'full_path_to_file');
-
-                $mail->bye;
+$mail->bye;
 
 =head1 DESCRIPTION
 
@@ -269,7 +262,7 @@ We will be notified, and then you'll automatically be notified of progress on yo
 
 =head1 AUTHORS
 
-Martin Vukovic, C<< <mvukovic at microbotica.es> >>
+Martin Vukovic, C<< mvukovic at microbotica.es >>
 
 Juan Jose 'Peco' San Martin, C<< <peco at cpan.org> >>
 
